let request = require('./requestLib');

let ENDPOINT_URL = process.env.ENDPOINT_URL;

exports.uploadFile = async function(req, res, tokenHandler) {
    await uploadFileToS3(req, res, tokenHandler);
};

let uploadFileToS3 = async function(req, res, tokenHandler) {
    if (Object.keys(req.files).length == 0) {
        res.redirect("/import?error=No file to upload");
        return;
    }

    if (!req.body.folder || req.body.folder.startsWith("Choose")) {
        res.redirect("/import?error=Please select a folder");
        return;
    }

    let file = req.files.x3File;

    try {
        let result = await getSignedUrl(req, req.body.folder, file.name, tokenHandler, true);

        await putToS3(req, result.uploadUrl, file);
        let splitTrackingUrl = result.trackingUrl.split('/');
        let trackingId = "";
        if (splitTrackingUrl.length > 0) {
            trackingId = splitTrackingUrl[splitTrackingUrl.length - 1];
        }

        res.redirect("/import?success=File upload succeed&trackingId=" + trackingId);
    } catch (e) {
        res.redirect("/import?error=" + e.message);
    }
};


let getSignedUrl = async function(req, folder, filename, tokenHandler, canRefreshToken) {

    console.log(ENDPOINT_URL + "/dataingestion/" + folder + "/?filename=" + filename);
    let result = await request.post(req, {headers: {'content-type' : 'application/json', 'Authorization': 'Bearer ' + tokenHandler.accessToken()}, url: ENDPOINT_URL + "/dataingestion/" + folder + "/?filename=" + filename}, true);
    if (result.statusCode === 201) {
        let body = JSON.parse(result.body);
        return body;
    } else if (result.statusCode === 401 && canRefreshToken) {
        await tokenHandler.getNewAccessTokenFromRefreshToken(req);
        return await getSignedUrl(folder, filename, tokenHandler, false);
    } else {
        let message = "An error occured";
        let body = JSON.parse(result.body);
        if (body && body.message) {
            message = body.message;
        }
        throw new Error(message);
    }
};


let putToS3 = async function(req, url, file) {
    let result = await request.put(req, {body: file.data.toString(), url: url}, true);
    if (result.statusCode !== 200) {
        let message = "An error occured";
        let body = JSON.parse(result.body);
        if (body && body.message) {
            message = body.message;
        }
       throw new Error(message);
    }
};
