const express = require('express');
const exphbs = require("express-handlebars");
const fileUpload = require("express-fileupload");
const app = express();
const bodyParser = require('body-parser');
const fs = require('fs')
const https = require('https')

const config = require('./lib/config.js');
const callbackHandler = require('./lib/callbackHandler');
const tokenHandler = require('./lib/tokenHandler');
const requestLib = require('./lib/requestLib');
const exportHandler = require('./lib/exportHandler');
const dataInHandler = require('./lib/dataIngestionHandler');
const fileTrackingHandler = require('./lib/fileTrackingHandler');
const port = 5050;

let envColor = process.env.COLOR;
let bgColor;
let buttonColor;
switch (envColor) {
    case "red":
        bgColor = "danger";
        buttonColor = "warning";
        break;
    case "grey":
        bgColor = "dark";
        buttonColor = "secondary";
        break;
    default:
        bgColor = "primary";
        buttonColor = "info";
        break;
}

app.use('/', express.static('app'));
app.use(bodyParser.json());       // to support JSON-encoded bodies
app.use(fileUpload());


app.get('/config', function (req, res) {
    config.get(req, res);
});

app.get('/settings', function (req, res) {
    res.render("settings", {bgColor: bgColor, btColor: buttonColor});
});

let redirectUrl = process.env.REDIRECT_URL ? process.env.REDIRECT_URL : process.env.ENV_URL + "/callback";
let urlParams = process.env.ENDPOINT_URL + "/token/authorise?client_id=" + process.env.CLIENT_ID + "&state=astate&redirect_uri=" + redirectUrl;
app.get('/pairingRequest', function (req, res) {
    res.render("pairingRequest", {bgColor: bgColor, btColor: buttonColor, url: urlParams, config_url: process.env.CONFIG_URL});
});

app.get('/callback', function (req, res) {
    callbackHandler.handleCallback(req, res, bgColor, buttonColor);
});

app.get('/api/curlCommands', function (req, res) {
    requestLib.getCurlCommands(req, res);
});

app.post('/api/initiateAccessToken', async function (req, res) {
    tokenHandler.initiate(req, res);
});

app.post('/api/refreshAccessToken', async function (req, res) {
    tokenHandler.refresh(req, res);
});

app.post('/api/deleteRefreshToken', async function (req, res) {
    tokenHandler.delete(req, res);
});
app.get('/api/folders', async function (req, res) {
    exportHandler.getFoldersList(req, res, tokenHandler);
});

app.post('/api/dataingestion', async function (req, res) {
    dataInHandler.uploadFile(req, res, tokenHandler);
});

app.post('/api/getTracking', async function (req, res) {
    fileTrackingHandler.getTracking(req, res, tokenHandler);
});

app.post('/api/decodeToken', async function (req, res) {
    tokenHandler.decodeCurrentToken(req, res);
});

app.get('/generateAccessToken', function (req, res) {
    res.render("accessToken", {
        bgColor: bgColor,
        btColor: buttonColor,
        code: req.query.code,
        refresh: false,
        inputTitle: "Access code"
    });
})

app.get('/refreshAccessToken', function (req, res) {
    res.render("accessToken", {bgColor: bgColor, btColor: buttonColor, code: tokenHandler.refreshToken(), refresh: true, inputTitle: "Refresh token", allowDelete: true});
});
app.get('/import', function (req, res) {
    res.render("import", {
        bgColor: bgColor,
        btColor: buttonColor,
        error: req.query.error,
        displayError: req.query.error ? "block" : "none",
        success: req.query.success,
        displaySuccess: req.query.success ? "block" : "none",
        trackingId: req.query.trackingId
    });
});

app.get('/export', function (req, res) {
    res.render("export", {bgColor: bgColor, btColor: buttonColor, accessToken: tokenHandler.accessToken(), folder: process.env.FOLDER});
});

app.get('/filetracking', function (req, res) {
    res.render("filetracking", {bgColor: bgColor, btColor: buttonColor, accessToken: tokenHandler.accessToken(), trackingId: req.query.id});
});

app.engine('handlebars', exphbs({defaultLayout: 'main', layoutsDir: 'views/layouts'}));
app.set('view engine', 'handlebars');
app.set('views', 'views');

https.createServer({
    key: fs.readFileSync('server.key'),
    cert: fs.readFileSync('server.cert')
  }, app).listen(port, function () {
});



